.. image:: ../artwork/logo.png
  :width: 200px
  :align: right

.. _installation:

Installation
============

Using Pip
---------

Unless you have a package manager that includes Graphcat, your first option for
installs should be Python setup tools like `pip`.  You can always install the
latest stable version of Graphcat and its required dependencies using::

    $ pip install graphcat

... following that, you'll be able to use all of Graphcat's features.

.. _From Source:

From Source
-----------

Finally, if you want to work with the latest, bleeding-edge Graphcat goodness,
you can install it using the source code::

    $ git clone https://github.com/shead-custom-design/graphcat
    $ cd graphcat
    $ sudo python setup.py install

The setup script installs Graphcat's required dependencies and copies Graphcat into
your Python site-packages directory, ready to go.

